@@ -50,11 +50,20 @@ class PackageBuild:
             'rm -rf build'
         ])
 
+    def git_build_clear(self):
+        logger.info('{} build clear'.format(self.name))
+        run_shell_list([
+            'rm -rf {}.egg-info'.format(self.name),
+            'rm -rf dist',
+            'rm -rf build',
+        ])
+
     def git_build(self):
         """
         git build
         """
         logger.info('{} build'.format(self.name))
+        self.git_build_clear()
         run_shell_list([
             'python3 setup.py build',  # 编译
             'python3 setup.py sdist',  # 生成 tar.gz
@@ -63,10 +72,8 @@ class PackageBuild:
 
             # twine register dist/*
             'twine upload dist/*',  # 发布包
-            'rm -rf {}.egg-info'.format(self.name),
-            'rm -rf dist',
-            'rm -rf build',
         ])
+        self.git_build_clear()
 
     def git_clean_history(self):
         """
